@@ -1,5 +1,4 @@
-#include <igraph_structural.h>
-#include <igraph_random.h>
+#include <igraph.h>
 #include "se2_label.h"
 
 static inline void global_label_proportions(igraph_t const* graph,
@@ -10,21 +9,21 @@ static inline void global_label_proportions(igraph_t const* graph,
   igraph_integer_t n_nodes = igraph_vcount(graph);
   igraph_integer_t acc = 0;
 
-  igraph_vector_init(&kout, n_nodes);
+  igraph_vector_init( &kout, n_nodes);
   igraph_strength(graph, &kout, igraph_vss_all(), IGRAPH_OUT, IGRAPH_LOOPS,
                   weights);
 
   for (igraph_integer_t i = 0; i < n_nodes; i++) {
-    VECTOR(*labels_heard)[LABEL(*partition)[i]] += VECTOR(kout)[i];
+    VECTOR(* labels_heard)[LABEL(* partition)[i]] += VECTOR(kout)[i];
   }
-  igraph_vector_destroy(&kout);
+  igraph_vector_destroy( &kout);
 
   for (igraph_integer_t i = 0; i < n_labels; i++) {
-    acc += VECTOR(*labels_heard)[i];
+    acc += VECTOR(* labels_heard)[i];
   }
 
   for (igraph_integer_t i = 0; i < n_labels; i++) {
-    VECTOR(*labels_heard)[i] /= acc;
+    VECTOR(* labels_heard)[i] /= acc;
   }
 }
 
@@ -38,7 +37,7 @@ static inline igraph_real_t edge_get_weight(igraph_t const* graph,
 
   igraph_integer_t eid;
   igraph_get_eid(graph, &eid, from, to, directed, false);
-  return VECTOR(*weights)[eid];
+  return VECTOR(* weights)[eid];
 }
 
 static inline void local_label_proportions(igraph_t const* graph,
@@ -52,19 +51,19 @@ static inline void local_label_proportions(igraph_t const* graph,
   igraph_real_t weight;
   igraph_bool_t directed = igraph_is_directed(graph);
 
-  igraph_vector_int_init(&neighbors, 0);
+  igraph_vector_int_init( &neighbors, 0);
   igraph_neighbors(graph, &neighbors, node_id, IGRAPH_IN);
-  n_neighbors = igraph_vector_int_size(&neighbors);
+  n_neighbors = igraph_vector_int_size( &neighbors);
   for (igraph_integer_t i = 0; i < n_neighbors; i++) {
     neighbor = VECTOR(neighbors)[i];
     weight = edge_get_weight(graph, weights, neighbor, node_id, directed);
-    VECTOR(*labels_heard)[LABEL(*partition)[neighbor]] += weight;
+    VECTOR(* labels_heard)[LABEL(* partition)[neighbor]] += weight;
   }
-  igraph_vector_int_destroy(&neighbors);
+  igraph_vector_int_destroy( &neighbors);
 
   *kin = 0;
   for (igraph_integer_t i = 0; i < n_labels; i++) {
-    *kin += VECTOR(*labels_heard)[i];
+    *kin += VECTOR(* labels_heard)[i];
   }
 }
 
@@ -84,20 +83,20 @@ static void se2_find_most_specific_labels_i(igraph_t const* graph,
   igraph_real_t label_specificity = 0, best_label_specificity = 0;
   igraph_integer_t best_label = -1;
 
-  igraph_vector_init(&labels_expected, max_label + 1);
-  igraph_vector_init(&labels_observed, max_label + 1);
+  igraph_vector_init( &labels_expected, max_label + 1);
+  igraph_vector_init( &labels_observed, max_label + 1);
 
   global_label_proportions(graph, weights, partition, &labels_expected,
                            max_label + 1);
 
   igraph_integer_t node_id = 0, label_id = 0;
   while ((node_id = se2_iterator_next(node_iter)) != -1) {
-    igraph_vector_null(&labels_observed);
+    igraph_vector_null( &labels_observed);
     local_label_proportions(graph, weights, partition, node_id,
                             &labels_observed, &node_kin, max_label + 1);
     while ((label_id = se2_iterator_next(label_iter)) != -1) {
       label_specificity = VECTOR(labels_observed)[label_id] -
-                          (node_kin * VECTOR(labels_expected)[label_id]);
+                          (node_kin* VECTOR(labels_expected)[label_id]);
       if ((best_label == -1) || (label_specificity >= best_label_specificity)) {
         best_label_specificity = label_specificity;
         best_label = label_id;
@@ -111,8 +110,8 @@ static void se2_find_most_specific_labels_i(igraph_t const* graph,
   se2_partition_commit_changes(partition);
 
   se2_iterator_destroy(label_iter);
-  igraph_vector_destroy(&labels_expected);
-  igraph_vector_destroy(&labels_observed);
+  igraph_vector_destroy( &labels_expected);
+  igraph_vector_destroy( &labels_observed);
 }
 
 void se2_find_most_specific_labels(igraph_t const* graph,
@@ -132,7 +131,7 @@ void se2_relabel_worst_nodes(igraph_t const* graph,
                              igraph_real_t const fraction_nodes_to_label)
 {
   igraph_integer_t n_nodes = igraph_vcount(graph);
-  igraph_integer_t n_nodes_to_relabel = fraction_nodes_to_label * n_nodes;
+  igraph_integer_t n_nodes_to_relabel = fraction_nodes_to_label* n_nodes;
   se2_iterator* node_iter = se2_iterator_k_worst_fit_nodes_init(partition,
                             n_nodes_to_relabel);
 
@@ -154,12 +153,12 @@ void se2_burst_large_communities(igraph_t const* graph,
   igraph_vector_int_t new_tags;
   igraph_integer_t node_id;
 
-  igraph_vector_int_init(&n_new_tags_cum, partition->max_label + 2);
-  igraph_vector_int_init(&n_nodes_to_move, partition->max_label + 1);
+  igraph_vector_int_init( &n_new_tags_cum, partition->max_label + 2);
+  igraph_vector_int_init( &n_nodes_to_move, partition->max_label + 1);
   while ((node_id = se2_iterator_next(node_iter)) != -1) {
-    if (se2_partition_community_size(partition, LABEL(*partition)[node_id]) >=
+    if (se2_partition_community_size(partition, LABEL(* partition)[node_id]) >=
         min_community_size) {
-      VECTOR(n_nodes_to_move)[LABEL(*partition)[node_id]]++;
+      VECTOR(n_nodes_to_move)[LABEL(* partition)[node_id]]++;
     }
   }
 
@@ -185,25 +184,25 @@ void se2_burst_large_communities(igraph_t const* graph,
 
   n_new_tags = VECTOR(n_new_tags_cum)[partition->max_label + 1];
 
-  igraph_vector_int_init(&new_tags, n_new_tags);
+  igraph_vector_int_init( &new_tags, n_new_tags);
   for (igraph_integer_t i = 0; i < n_new_tags; i++) {
     VECTOR(new_tags)[i] = se2_partition_new_label(partition);
   }
 
   igraph_integer_t current_label;
   while ((node_id = se2_iterator_next(node_iter)) != -1) {
-    current_label = LABEL(*partition)[node_id];
+    current_label = LABEL(* partition)[node_id];
     if (se2_partition_community_size(partition, current_label) >=
         min_community_size) {
-      RELABEL(*partition)[node_id] =
+      RELABEL(* partition)[node_id] =
         VECTOR(new_tags)[RNG_INTEGER(VECTOR(n_new_tags_cum)[current_label],
                                      VECTOR(n_new_tags_cum)[current_label + 1] - 1)];
     }
   }
 
-  igraph_vector_int_destroy(&new_tags);
-  igraph_vector_int_destroy(&n_nodes_to_move);
-  igraph_vector_int_destroy(&n_new_tags_cum);
+  igraph_vector_int_destroy( &new_tags);
+  igraph_vector_int_destroy( &n_nodes_to_move);
+  igraph_vector_int_destroy( &n_new_tags_cum);
   se2_iterator_destroy(node_iter);
 
   se2_partition_commit_changes(partition);
@@ -232,9 +231,9 @@ static void se2_best_merges(igraph_t const* graph,
   igraph_vector_t to_edge_probability;
 
   igraph_eit_create(graph, igraph_ess_all(IGRAPH_EDGEORDER_ID), &eit);
-  igraph_matrix_init(&crosstalk, n_labels, n_labels);
-  igraph_vector_init(&from_edge_probability, n_labels);
-  igraph_vector_init(&to_edge_probability, n_labels);
+  igraph_matrix_init( &crosstalk, n_labels, n_labels);
+  igraph_vector_init( &from_edge_probability, n_labels);
+  igraph_vector_init( &to_edge_probability, n_labels);
 
   igraph_vector_int_fill(merge_candidates, -1);
 
@@ -248,9 +247,9 @@ static void se2_best_merges(igraph_t const* graph,
   while (!IGRAPH_EIT_END(eit)) {
     eid = IGRAPH_EIT_GET(eit);
     MATRIX(crosstalk,
-           LABEL(*partition)[IGRAPH_FROM(graph, eid)],
-           LABEL(*partition)[IGRAPH_TO(graph, eid)]) +=
-             weights ? VECTOR(*weights)[eid] : 1;
+           LABEL(* partition)[IGRAPH_FROM(graph, eid)],
+           LABEL(* partition)[IGRAPH_TO(graph, eid)]) +=
+             weights ? VECTOR(* weights)[eid] : 1;
     IGRAPH_EIT_NEXT(eit);
   }
 
@@ -260,8 +259,8 @@ static void se2_best_merges(igraph_t const* graph,
     }
   }
 
-  igraph_matrix_rowsum(&crosstalk, &from_edge_probability);
-  igraph_matrix_colsum(&crosstalk, &to_edge_probability);
+  igraph_matrix_rowsum( &crosstalk, &from_edge_probability);
+  igraph_matrix_colsum( &crosstalk, &to_edge_probability);
 
   igraph_real_t modularity_delta;
   for (igraph_integer_t i = 0; i < n_labels; i++) {
@@ -271,22 +270,22 @@ static void se2_best_merges(igraph_t const* graph,
         (VECTOR(from_edge_probability)[i] * VECTOR(to_edge_probability)[j]) -
         (VECTOR(from_edge_probability)[j] * VECTOR(to_edge_probability)[i]);
 
-      if (modularity_delta > VECTOR(*modularity_change)[i]) {
-        VECTOR(*modularity_change)[i] = modularity_delta;
-        VECTOR(*merge_candidates)[i] = j;
+      if (modularity_delta > VECTOR(* modularity_change)[i]) {
+        VECTOR(* modularity_change)[i] = modularity_delta;
+        VECTOR(* merge_candidates)[i] = j;
       }
 
-      if (modularity_delta > VECTOR(*modularity_change)[j]) {
-        VECTOR(*modularity_change)[j] = modularity_delta;
-        VECTOR(*merge_candidates)[j] = i;
+      if (modularity_delta > VECTOR(* modularity_change)[j]) {
+        VECTOR(* modularity_change)[j] = modularity_delta;
+        VECTOR(* merge_candidates)[j] = i;
       }
     }
   }
 
-  igraph_eit_destroy(&eit);
-  igraph_matrix_destroy(&crosstalk);
-  igraph_vector_destroy(&from_edge_probability);
-  igraph_vector_destroy(&to_edge_probability);
+  igraph_eit_destroy( &eit);
+  igraph_matrix_destroy( &crosstalk);
+  igraph_vector_destroy( &from_edge_probability);
+  igraph_vector_destroy( &to_edge_probability);
 }
 
 /* Since used labels are not necessarily sequential, modularity change can be
@@ -299,7 +298,7 @@ igraph_real_t se2_modularity_median(se2_partition* partition,
   se2_iterator* label_iter = se2_iterator_random_label_init(partition, 0);
   igraph_real_t res;
 
-  igraph_vector_init(&modularity_change_without_gaps, partition->n_labels);
+  igraph_vector_init( &modularity_change_without_gaps, partition->n_labels);
 
   igraph_integer_t label_id = 0;
   igraph_integer_t label_i = 0;
@@ -309,9 +308,9 @@ igraph_real_t se2_modularity_median(se2_partition* partition,
     label_i++;
   }
 
-  res = se2_vector_median(&modularity_change_without_gaps);
+  res = se2_vector_median( &modularity_change_without_gaps);
 
-  igraph_vector_destroy(&modularity_change_without_gaps);
+  igraph_vector_destroy( &modularity_change_without_gaps);
   se2_iterator_destroy(label_iter);
 
   return res;
@@ -329,8 +328,8 @@ igraph_bool_t se2_merge_well_connected_communities(igraph_t const* graph,
   igraph_integer_t n_positive_changes = 0;
   igraph_integer_t n_merges = 0;
 
-  igraph_vector_int_init(&merge_candidates, max_label + 1);
-  igraph_vector_init(&modularity_change, max_label + 1);
+  igraph_vector_int_init( &merge_candidates, max_label + 1);
+  igraph_vector_init( &modularity_change, max_label + 1);
 
   se2_best_merges(graph, weights, partition, &merge_candidates,
                   &modularity_change,
@@ -356,10 +355,10 @@ igraph_bool_t se2_merge_well_connected_communities(igraph_t const* graph,
        se2_partition_community_size(partition, VECTOR(merge_candidates)[i]));
   }
 
-  min_merge_improvement = igraph_vector_sum(&modularity_change) /
+  min_merge_improvement = igraph_vector_sum( &modularity_change) /
                           n_positive_changes;
 
-  if (min_merge_improvement < (0.5 * *max_prev_merge_threshold)) {
+  if (min_merge_improvement < (0.5 ** max_prev_merge_threshold)) {
     goto cleanup_early;
   }
 
@@ -373,9 +372,9 @@ igraph_bool_t se2_merge_well_connected_communities(igraph_t const* graph,
   igraph_vector_bool_t merged_labels;
   igraph_vector_int_t sort_index;
 
-  igraph_vector_bool_init(&merged_labels, max_label + 1);
-  igraph_vector_int_init(&sort_index, max_label + 1);
-  igraph_vector_qsort_ind(&modularity_change, &sort_index, IGRAPH_DESCENDING);
+  igraph_vector_bool_init( &merged_labels, max_label + 1);
+  igraph_vector_int_init( &sort_index, max_label + 1);
+  igraph_vector_qsort_ind( &modularity_change, &sort_index, IGRAPH_DESCENDING);
 
   if (VECTOR(modularity_change)[VECTOR(sort_index)[0]] <=
       min_merge_improvement) {
@@ -416,12 +415,12 @@ igraph_bool_t se2_merge_well_connected_communities(igraph_t const* graph,
   }
 
 cleanup_sort:
-  igraph_vector_bool_destroy(&merged_labels);
-  igraph_vector_int_destroy(&sort_index);
+  igraph_vector_bool_destroy( &merged_labels);
+  igraph_vector_int_destroy( &sort_index);
 
 cleanup_early:
-  igraph_vector_int_destroy(&merge_candidates);
-  igraph_vector_destroy(&modularity_change);
+  igraph_vector_int_destroy( &merge_candidates);
+  igraph_vector_destroy( &modularity_change);
 
   return n_merges == 0;
 }
